==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Activer la sauvegarde automatique</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Intervalle pour la sauvegarde automatique :</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Autosave Directory:</source>
        <translation type="obsolete">Dossier :</translation>
    </message>
    <message>
        <source>auto</source>
        <translation type="obsolete">auto</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>Charger/Enregistrer</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>Sauvegarde automatique</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Autosave failed:</source>
        <translation>Sauvegarde automatique échoué:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Sauvegarde automatique terminé.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation>Un fichier de &apos;sauvegarde automatique&apos; pour un dessin sans titre a été trouvé.
Voulez-vous le récupérer?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation>%1 fichiers de &apos;sauvegarde automatique&apos; pour dessins sans titre ont été trouvés.
Voulez-vous les récupérer?</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Recovered</source>
        <translation>Récupéré</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Récupérer fichier?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Un fichier de &apos;sauvegarde automatique&apos; pour &apos;%1&apos; a été trouvé.
Voulez-vous le récupérer?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Impossible de renommer fichier :</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Fichier de sauvegarde automatique renommé :</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Déplacé fichier original à :</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Impossible de supprimer le fichier :</translation>
    </message>
    <message>
        <source>Cannot remove file: </source>
        <translation type="obsolete">Impossible de supprimer le fichier : </translation>
    </message>
    <message>
        <source>Cannot rename backup file: </source>
        <translation type="obsolete">Impossible de renommer le fichier de sauvegarde : </translation>
    </message>
    <message>
        <source>Moved autosave backup file to: </source>
        <translation type="obsolete">Fichier de sauvegarde automatique renommé : </translation>
    </message>
    <message>
        <location line="-124"/>
        <source>Recover Files?</source>
        <translation>Récupérer des fichiers?</translation>
    </message>
    <message>
        <source>Choose Autosave Directory</source>
        <translation type="obsolete">Choisissez le dossier d&apos;enregistrement automatique</translation>
    </message>
    <message>
        <location line="-57"/>
        <source>Autosaving to:</source>
        <translation>Sauvegarde automatique de :</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Activer la sauvegarde automatique</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Intervalle pour la sauvegarde automatique :</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Autosave Directory:</source>
        <translation type="obsolete">Dossier :</translation>
    </message>
    <message>
        <source>auto</source>
        <translation type="obsolete">auto</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Charger/Enregistrer</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>Sauvegarde automatique</translation>
    </message>
    <message>
        <source>Open/Save</source>
        <translation type="vanished">Charger/Enregistrer</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Autosave failed:</source>
        <translation>Sauvegarde automatique échoué:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Sauvegarde automatique terminé.</translation>
    </message>
    <message>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="vanished">Un fichier de &apos;sauvegarde automatique&apos; pour un dessin sans titre a été trouvé.
Voulez-vous le récupérer?</translation>
    </message>
    <message>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="vanished">%1 fichiers de &apos;sauvegarde automatique&apos; pour dessins sans titre ont été trouvés.
Voulez-vous les récupérer?</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation>
            <numerusform>%n fichier de &apos;sauvegarde automatique&apos; pour un dessin sans titre a été trouvé.
Voulez-vous le récupérer?</numerusform>
            <numerusform>%n fichiers de &apos;sauvegarde automatique&apos; pour dessins sans titre ont été trouvés.
Voulez-vous les récupérer?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Recovered</source>
        <translation>Récupéré</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Récupérer fichier?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Un fichier de &apos;sauvegarde automatique&apos; pour &apos;%1&apos; a été trouvé.
Voulez-vous le récupérer?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Impossible de renommer fichier :</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation>Fichier de sauvegarde automatique renommé :</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation>Déplacé fichier original à :</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation>Impossible de supprimer le fichier :</translation>
    </message>
    <message>
        <source>Cannot remove file: </source>
        <translation type="obsolete">Impossible de supprimer le fichier : </translation>
    </message>
    <message>
        <source>Cannot rename backup file: </source>
        <translation type="obsolete">Impossible de renommer le fichier de sauvegarde : </translation>
    </message>
    <message>
        <source>Moved autosave backup file to: </source>
        <translation type="obsolete">Fichier de sauvegarde automatique renommé : </translation>
    </message>
    <message>
        <location line="-124"/>
        <source>Recover Files?</source>
        <translation>Récupérer des fichiers?</translation>
    </message>
    <message>
        <source>Choose Autosave Directory</source>
        <translation type="obsolete">Choisissez le dossier d&apos;enregistrement automatique</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Autosaving to:</source>
        <translation>Sauvegarde automatique de :</translation>
    </message>
</context>
</TS>
